==> telepathy-gabble-0.3.0.tar.gz: telepathy-gabble-0.3.0/src/gabble-media-stream-signals-marshal.h <==

#ifndef __gabble_media_stream_marshal_MARSHAL_H__
#define __gabble_media_stream_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,BOXED (gabble-media-stream-signals-marshal.list:1) */
extern void gabble_media_stream_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
                                                            const GValue *param_values,
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);

/* VOID:STRING (gabble-media-stream-signals-marshal.list:2) */
#define gabble_media_stream_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:STRING,STRING (gabble-media-stream-signals-marshal.list:3) */
extern void gabble_media_stream_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:BOXED (gabble-media-stream-signals-marshal.list:4) */
#define gabble_media_stream_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:BOXED (gabble-media-stream-signals-marshal.list:5) */

/* VOID:BOOLEAN (gabble-media-stream-signals-marshal.list:6) */
#define gabble_media_stream_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

G_END_DECLS

#endif /* __gabble_media_stream_marshal_MARSHAL_H__ */

==> telepathy-gabble_0.3.10.orig.tar.gz: telepathy-gabble-0.3.10/src/gabble-media-stream-signals-marshal.h <==

#ifndef __gabble_media_stream_marshal_MARSHAL_H__
#define __gabble_media_stream_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,BOXED (gabble-media-stream-signals-marshal.list:1) */
extern void gabble_media_stream_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
                                                            const GValue *param_values,
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);

/* VOID:STRING,STRING (gabble-media-stream-signals-marshal.list:2) */
extern void gabble_media_stream_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:UINT,STRING (gabble-media-stream-signals-marshal.list:3) */
extern void gabble_media_stream_marshal_VOID__UINT_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* __gabble_media_stream_marshal_MARSHAL_H__ */
